@@ -15,6 +15,8 @@
 
 #include <osm/geomath.h>
 
+#include <QTimeZone>
+
 using namespace KOSMIndoorMap;
 
 MapLevel::MapLevel(int level)
@@ -83,6 +85,9 @@ public:
 
     std::map<MapLevel, std::vector<OSM::Element>> m_levelMap;
     std::map<MapLevel, std::size_t> m_dependentElementCounts;
+
+    QString m_regionCode;
+    QTimeZone m_timeZone;
 };
 }
 
@@ -156,6 +161,7 @@ void MapData::processElements()
     const auto buildingLevelsUndergroundTag = d->m_dataSet.tagKey("building:levels:underground");
     const auto maxLevelTag = d->m_dataSet.tagKey("max_level");
     const auto minLevelTag = d->m_dataSet.tagKey("min_level");
+    const auto countryTag = d->m_dataSet.tagKey("addr:country");
 
     MapCSSParser p;
     auto filter = p.parse(QStringLiteral(":/org.kde.kosmindoormap/assets/css/input-filter.mapcss"));
@@ -171,6 +177,14 @@ void MapData::processElements()
             return;
         }
 
+        // attempt to detect the country we are in
+        if (d->m_regionCode.isEmpty()) {
+            const auto countryCode = e.tagValue(countryTag);
+            if (countryCode.size() == 2 && std::isupper(countryCode[0]) && std::isupper(countryCode[1])) {
+                d->m_regionCode = QString::fromUtf8(countryCode);
+            }
+        }
+
         // apply the input filter, anything that explicitly got opacity 0 will be discarded
         bool isDependentElement = false;
         MapCSSState filterState;
@@ -301,4 +315,29 @@ float MapData::radius() const
     return std::max(OSM::distance(d->m_bbox.center(), d->m_bbox.min), OSM::distance(d->m_bbox.center(), d->m_bbox.max));
 }
 
+QString MapData::regionCode() const
+{
+    return d->m_regionCode;
+}
+
+void MapData::setRegionCode(const QString &regionCode)
+{
+    d->m_regionCode = regionCode;
+}
+
+QTimeZone MapData::timeZone() const
+{
+    return d->m_timeZone;
+}
+
+void MapData::setTimeZone(const QTimeZone &tz)
+{
+    d->m_timeZone = tz;
+}
+
+QString MapData::timeZoneId() const
+{
+    return QString::fromUtf8(d->m_timeZone.id());
+}
+
 #include "moc_mapdata.cpp"
